/*******************************************************************************
* File Name: PGA.h  
* Version 1.20
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the PGA User Module.
*
*   Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/



#include "cytypes.h"
#include "cyfitter.h"

#if !defined(CY_PGA_PGA_H) 
#define CY_PGA_PGA_H 

/***************************************
*        Function Prototypes 
***************************************/

void    PGA_Start(void);
void    PGA_Stop(void);
void    PGA_SetPower(uint8 power);
void    PGA_SetGain(uint8 gain);


/***************************************
*       Initialization Values
***************************************/

#define PGA_DEFAULT_GAIN  0
#define PGA_VREF_MODE     (0 ? 0x00 : PGA_GNDVREF_E )
#define PGA_DEFAULT_POWER 3
/* #define PGA_ACLK_ENABLE   ((0 ? 0 : 1) | 0 )  */
#define PGA_ACLK_ENABLE   0 

/***************************************
*              Registers        
***************************************/

#define PGA_CR0    (* (reg8 *) PGA_SC__CR0 )
#define PGA_CR1    (* (reg8 *) PGA_SC__CR1 )
#define PGA_CR2    (* (reg8 *) PGA_SC__CR2 )
#define PGA_PWRMGR (* (reg8 *) PGA_SC__PM_ACT_CFG )  /* Power manager */
#define PGA_BST    (* (reg8 *) PGA_SC__BST )

#if (PGA_ACLK_ENABLE)
   #define PGA_ACLK_PWRMGR (* (reg8 *) PGA_ScBoostClk__PM_ACT_CFG )  /* Power manager */
   #define PGA_ACLK_ACT_PWR_EN   PGA_ScBoostClk__PM_ACT_MSK /* Power enable mask */
#endif

/***************************************
*              Constants        
***************************************/

/* Power constants for SetPower function */
#define PGA_MINPOWER   0x00u
#define PGA_LOWPOWER   0x01u
#define PGA_MEDPOWER   0x02u
#define PGA_HIGHPOWER  0x03u

/* Constants for SetGain function */
#define PGA_GAIN_01    0x00u
#define PGA_GAIN_02    0x01u
#define PGA_GAIN_04    0x02u
#define PGA_GAIN_08    0x03u
#define PGA_GAIN_16    0x04u
#define PGA_GAIN_24    0x05u
#define PGA_GAIN_25    0x06u
#define PGA_GAIN_32    0x07u
#define PGA_GAIN_48    0x08u
#define PGA_GAIN_50    0x09u
#define PGA_GAIN_MAX   0x09u

/* Constant for VDDA Threshold */
#define PGA_CYDEV_VDDA_MV  CYDEV_VDDA_MV
#define PGA_VDDA_THRESHOLD_MV 3500u

/* SC_MISC constants */
#define PGA_PUMP_FORCE     0x20u
#define PGA_PUMP_AUTO      0x10u
#define PGA_DIFF_PGA_1_3   0x02u
#define PGA_DIFF_PGA_0_2   0x01u


/* CR0 SC/CT Control Register 0 definitions */
#define PGA_MODE_PGA      0x0Cu

/* CR1 SC/CT Control Register 1 definitions */
/* Bit Field  SC_COMP_ENUM                  */
#define PGA_COMP_MASK     0x0Cu
#define PGA_COMP_3P0PF    0x00u
#define PGA_COMP_3P6PF    0x04u
#define PGA_COMP_4P35PF   0x08u
#define PGA_COMP_5P1PF    0x0Cu

/* Bit Field  SC_DIV2_ENUM                  */
#define PGA_DIV2_MASK     0x10u
#define PGA_DIV2_DISABLE  0x00u
#define PGA_DIV2_ENABLE   0x10u

/* Bit Field  SC_DRIVE_ENUM                 */
#define PGA_DRIVE_MASK    0x03u
#define PGA_DRIVE_280UA   0x00u
#define PGA_DRIVE_420UA   0x01u
#define PGA_DRIVE_530UA   0x02u
#define PGA_DRIVE_650UA   0x03u

/* Bit Field  SC_PGA_MODE_ENUM              */
#define PGA_PGA_MODE_MASK 0x20u
#define PGA_PGA_INV       0x00u
#define PGA_PGA_NINV      0x20u

/* CR2 SC/CT Control Register 2 definitions */

/* Bit Field  SC_BIAS_CONTROL_ENUM          */
#define PGA_BIAS_MASK     0x01u
#define PGA_BIAS_NORMAL   0x00u
#define PGA_BIAS_LOW      0x01u

/* Bit Field  SC_PGA_GNDVREF_ENUM           */
#define PGA_GNDVREF_MASK  0x80u
#define PGA_GNDVREF_DI    0x00u
#define PGA_GNDVREF_E     0x80u

/* Bit Field  SC_R20_40B_ENUM               */
#define PGA_R20_40B_MASK  0x02u
#define PGA_R20_40B_40K   0x00u
#define PGA_R20_40B_20K   0x02u

/* Bit Field  SC_REDC_ENUM                  */
#define PGA_REDC_MASK     0x0Cu
#define PGA_REDC_00       0x00u
#define PGA_REDC_01       0x04u
#define PGA_REDC_10       0x08u
#define PGA_REDC_11       0x0Cu

/* Bit Field  SC_RVAL_ENUM                  */
#define PGA_RVAL_MASK     0x70u
#define PGA_RVAL_20K      0x00u
#define PGA_RVAL_30K      0x10u
#define PGA_RVAL_40K      0x20u
#define PGA_RVAL_60K      0x30u
#define PGA_RVAL_120K     0x40u
#define PGA_RVAL_250K     0x50u
#define PGA_RVAL_500K     0x60u
#define PGA_RVAL_1000K    0x70u

/* Bit Field  PGA_GAIN_ENUM    */
#define PGA_PGA_GAIN_MASK  0x72u
#define PGA_PGA_GAIN_01    0x00u
#define PGA_PGA_GAIN_02    0x10u
#define PGA_PGA_GAIN_04    0x20u
#define PGA_PGA_GAIN_08    0x30u
#define PGA_PGA_GAIN_16    0x40u
#define PGA_PGA_GAIN_24    0x50u
#define PGA_PGA_GAIN_25    0x70u
#define PGA_PGA_GAIN_32    0x52u
#define PGA_PGA_GAIN_48    0x62u
#define PGA_PGA_GAIN_50    0x72u

/* PM_ACT_CFG (Active Power Mode CFG Register)     */ 
#define PGA_ACT_PWR_EN   PGA_SC__PM_ACT_MSK /* Power enable mask */

/* Pump Register for SC block */
#define PGA_SC_MISC (* (reg8 *) CYDEV_ANAIF_RT_SC_MISC)

#endif /* CY_PGA_PGA_H */

/* [] END OF FILE */

